@@ -1,10 +1,11 @@
 use crate::traits::r#async::{AsyncMigrate, AsyncQuery, AsyncTransaction};
 use crate::Migration;
 use async_trait::async_trait;
-use chrono::{DateTime, Local};
 use mysql_async_driver::{
     prelude::Queryable, Error as MError, IsolationLevel, Pool, Transaction as MTransaction, TxOpts,
 };
+use time::format_description::well_known::Rfc3339;
+use time::OffsetDateTime;
 
 async fn query_applied_migrations<'a>(
     mut transaction: MTransaction<'a>,
@@ -18,9 +19,8 @@ async fn query_applied_migrations<'a>(
             let (version, name, applied_on, checksum): (i32, String, String, String) =
                 mysql_async_driver::from_row(row);
 
-            let applied_on = DateTime::parse_from_rfc3339(&applied_on)
-                .unwrap()
-                .with_timezone(&Local);
+            // Safe to call unwrap, as we stored it in RFC3339 format on the database
+            let applied_on = OffsetDateTime::parse(&applied_on, &Rfc3339).unwrap();
             Migration::applied(
                 version,
                 name,
