@@ -21,10 +21,10 @@ pub use postgres;
 pub use mysql;
 
 #[cfg(feature = "tokio-postgres")]
-pub use tokio_postgres;
+pub use tokio_postgres_driver as tokio_postgres;
 
 #[cfg(feature = "mysql_async")]
-pub use mysql_async;
+pub use mysql_async_driver as mysql_async;
 
-#[cfg(feature = "tokio")]
-pub use tokio;
+#[cfg(feature = "tiberius")]
+pub use tiberius_driver as tiberius;
